Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewTigerTonicLogger ¶
func NewTigerTonicLogger(log logging.Logger) tigertonic.Logger
Types ¶
type Initer ¶
type Initer interface {
Init(mux *tigertonic.TrieServeMux) *tigertonic.TrieServeMux
}
Initer is for initializing the api endpoints for a module
type LoggerHolder ¶
type Server ¶
type Server struct {
Mux *tigertonic.TrieServeMux
Port int
Server *tigertonic.Server
// App handles all the required information about the application
// eg. database connections, singletons etc
App interface{}
// DebugEnabled holds the status of the server's debug level
DebugEnabled bool
}
type TigerTonicLogger ¶
type TigerTonicLogger struct {
// contains filtered or unexported fields
}
func (*TigerTonicLogger) Print ¶
func (t *TigerTonicLogger) Print(v ...interface{})
func (*TigerTonicLogger) Printf ¶
func (t *TigerTonicLogger) Printf(format string, v ...interface{})
func (*TigerTonicLogger) Println ¶
func (t *TigerTonicLogger) Println(v ...interface{})
Click to show internal directories.
Click to hide internal directories.